==> photoprint_0.4.1.orig.tar.gz: photoprint-0.4.1/miscwidgets/squiggledata.cpp <==
/* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */

#ifdef __SUNPRO_C
#pragma align 4 (my_pixbuf)
#endif
#ifdef __GNUC__
static const guint8 my_pixbuf[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 my_pixbuf[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2895) */
  "\0\0\13g"
  /* pixdata_type (0x2010002) */
  "\2\1\0\2"
  /* rowstride (160) */
  "\0\0\0\240"
  /* width (40) */
  "\0\0\0("
  /* height (30) */
  "\0\0\0\36"
  /* pixel_data: */
  "\212\0\0\0\377\4\5\5\5\377(((\377...\377\15\15\15\377\236\0\0\0\377\2"
  "\3\3\3\377\7\7\7\377\204\0\0\0\377\4PPP\377\211\211\211\377\200\200\200"
  "\377EEE\377\236\0\0\0\377\3'''\377!!!\377\10\10\10\377\202\0\0\0\377"
  "\5CCC\377\207\207\207\377\203\203\203\377\210\210\210\377VVV\377\202"
  "\0\0\0\377\4""555\377ppp\377aaa\377\24\24\24\377\227\0\0\0\377\7&&&\377"
  "AAA\377;;;\377\10\10\10\377\0\0\0\377999\377~~~\377\202\201\201\201\377"
  "\10\210\210\210\377\27\27\27\377\0\0\0\377KKK\377\210\210\210\377\205"
  "\205\205\377\204\204\204\377eee\377\203\0\0\0\377\5\35\35\35\377\200"
  "\200\200\377\243\243\243\377\207\207\207\377\26\26\26\377\216\0\0\0\377"
  "\22\5\5\5\377PPP\377QQQ\377>>>\377\0\0\0\377\34\34\34\377xxx\377\200"
  "\200\200\377\177\177\177\377\203\203\203\377YYY\377\0\0\0\377AAA\377"
  "\206\206\206\377\203\203\203\377~~~\377\205\205\205\377www\377\202\0"
  "\0\0\377\6jjj\377\254\254\254\377\246\246\246\377\243\243\243\377\251"
  "\251\251\377\223\223\223\377\216\0\0\0\377\16:::\377^^^\377YYY\377''"
  "'\377\0\0\0\377nnn\377|||\377}}}\377\177\177\177\377rrr\377\0\0\0\377"
  "555\377\205\205\205\377\177\177\177\377\202~~~\377\13\204\204\204\377"
  "KKK\377\0\0\0\377\223\223\223\377\247\247\247\377\231\231\231\377\232"
  "\232\232\377\233\233\233\377\241\241\241\377\251\251\251\377\5\5\5\377"
  "\215\0\0\0\377\6___\377bbb\377XXX\377\14\14\14\377ccc\377zzz\377\202"
  "}}}\377\4uuu\377---\377000\377\201\201\201\377\202~~~\377\202}}}\377"
  "\6sss\377\"\"\"\377\221\221\221\377\243\243\243\377\226\226\226\377\230"
  "\230\230\377\202\232\232\232\377\2\247\247\247\377\225\225\225\377\215"
  "\0\0\0\377\14\32\32\32\377mmm\377ddd\377GGG\377OOO\377www\377|||\377"
  "{{{\377uuu\377UUU\377===\377~~~\377\202|||\377\10\177\177\177\377|||"
  "\377sss\377^^^\377\212\212\212\377\240\240\240\377\225\225\225\377\224"
  "\224\224\377\202\233\233\233\377\3\235\235\235\377\262\262\262\37733"
  "3\377\214\0\0\0\377\33\2\2\2\377TTT\377kkk\377aaa\377___\377nnn\377x"
  "xx\377}}}\377uuu\377eee\377XXX\377zzz\377{{{\377zzz\377\200\200\200\377"
  "~~~\377vvv\377qqq\377\222\222\222\377\232\232\232\377\227\227\227\377"
  "\224\224\224\377\233\233\233\377\234\234\234\377\235\235\235\377\252"
  "\252\252\377\206\206\206\377\215\0\0\0\377\10\23\23\23\377ppp\377jjj"
  "\377ppp\377nnn\377rrr\377}}}\377www\377\202lll\377\21www\377{{{\377x"
  "xx\377\200\200\200\377\177\177\177\377xxx\377vvv\377\224\224\224\377"
  "\231\231\231\377\226\226\226\377\224\224\224\377\231\231\231\377\235"
  "\235\235\377\234\234\234\377\245\245\245\377\256\256\256\377\21\21\21"
  "\377\215\0\0\0\377\2'''\377uuu\377\202www\377\26lll\377www\377yyy\377"
  "ooo\377vvv\377uuu\377yyy\377vvv\377}}}\377\202\202\202\377zzz\377www"
  "\377\223\223\223\377\231\231\231\377\227\227\227\377\224\224\224\377"
  "\226\226\226\377\236\236\236\377\237\237\237\377\242\242\242\377\266"
  "\266\266\377FFF\377\216\0\0\0\377\1***\377\202yyy\377\26ttt\377mmm\377"
  "xxx\377qqq\377www\377yyy\377zzz\377yyy\377{{{\377\204\204\204\377\200"
  "\200\200\377zzz\377\215\215\215\377\231\231\231\377\227\227\227\377\225"
  "\225\225\377\221\221\221\377\237\237\237\377\243\243\243\377\244\244"
  "\244\377\262\262\262\377\177\177\177\377\202\0\0\0\377\4)))\377zzz\377"
  "\221\221\221\377PPP\377\211\0\0\0\377\10\20\20\20\377ddd\377ttt\377d"
  "dd\377nnn\377qqq\377uuu\377}}}\377\202yyy\377\1vvv\377\202\204\204\204"
  "\377\7\202\202\202\377\212\212\212\377\231\231\231\377\227\227\227\377"
  "\230\230\230\377\223\223\223\377\217\217\217\377\202\244\244\244\377"
  "\2\253\253\253\377\250\250\250\377\202\0\0\0\377\6\247\247\247\377\334"
  "\334\334\377\323\323\323\377\321\321\321\377\334\334\334\377~~~\377\212"
  "\0\0\0\377\15\13\13\13\377***\377vvv\377xxx\377\177\177\177\377|||\377"
  "{{{\377ttt\377}}}\377\210\210\210\377\205\205\205\377\211\211\211\377"
  "\230\230\230\377\202\227\227\227\377\17\224\224\224\377vvv\377\250\250"
  "\250\377\253\253\253\377\250\250\250\377\260\260\260\377\34\34\34\377"
  "333\377\321\321\321\377\316\316\316\377\275\275\275\377\271\271\271\377"
  "\273\273\273\377\304\304\304\377\336\336\336\377\213\0\0\0\377\7ppp\377"
  "}}}\377~~~\377}}}\377{{{\377www\377ppp\377\203\212\212\212\377\11\230"
  "\230\230\377\227\227\227\377\230\230\230\377\227\227\227\377\201\201"
  "\201\377\245\245\245\377\264\264\264\377\257\257\257\377\255\255\255"
  "\377\202uuu\377\2\323\323\323\377\304\304\304\377\202\271\271\271\377"
  "\202\274\274\274\377\3\275\275\275\377\344\344\344\377&&&\377\211\0\0"
  "\0\377\27:::\377\202\202\202\377\201\201\201\377\177\177\177\377}}}\377"
  "zzz\377fff\377\204\204\204\377\220\220\220\377\215\215\215\377\227\227"
  "\227\377\231\231\231\377\227\227\227\377\233\233\233\377|||\377\225\225"
  "\225\377\267\267\267\377\263\263\263\377\260\260\260\377\255\255\255"
  "\377\250\250\250\377\304\304\304\377\275\275\275\377\202\270\270\270"
  "\377\1\271\271\271\377\203\274\274\274\377\2\345\345\345\377\21\21\21"
  "\377\211\0\0\0\377\2hhh\377\206\206\206\377\202\200\200\200\377\22\177"
  "\177\177\377eee\377hhh\377\225\225\225\377\220\220\220\377\226\226\226"
  "\377\232\232\232\377\226\226\226\377\237\237\237\377\223\223\223\377"
  "QQQ\377\277\277\277\377\265\265\265\377\260\260\260\377\261\261\261\377"
  "\272\272\272\377\273\273\273\377\271\271\271\377\203\270\270\270\377"
  "\1\271\271\271\377\202\272\272\272\377\2\302\302\302\377\324\324\324"
  "\377\212\0\0\0\377\7fff\377\205\205\205\377\177\177\177\377\205\205\205"
  "\377sss\377666\377\227\227\227\377\202\226\226\226\377\11\230\230\230"
  "\377\227\227\227\377\237\237\237\377\246\246\246\377\34\34\34\377\252"
  "\252\252\377\275\275\275\377\263\263\263\377\262\262\262\377\204\270"
  "\270\270\377\4\275\275\275\377\276\276\276\377\265\265\265\377\276\276"
  "\276\377\202\272\272\272\377\7\302\302\302\377zzz\377\0\0\0\377]]]\377"
  "\255\255\255\377\310\310\310\377\222\222\222\377\205\0\0\0\377\22""0"
  "00\377|||\377\205\205\205\377www\377\16\16\16\377ooo\377\234\234\234"
  "\377\226\226\226\377\230\230\230\377\227\227\227\377\235\235\235\377"
  "\255\255\255\377DDD\377###\377\314\314\314\377\264\264\264\377\265\265"
  "\265\377\267\267\267\377\203\270\270\270\377\5\301\301\301\377\317\317"
  "\317\377nnn\377\235\235\235\377\275\275\275\377\202\272\272\272\377\10"
  "\302\302\302\377\240\240\240\377\321\321\321\377\333\333\333\377\320"
  "\320\320\377\322\322\322\377\340\340\340\377\327\327\327\377\205\0\0"
  "\0\377\20\36\36\36\377222\377\0\0\0\377\36\36\36\377\247\247\247\377"
  "\231\231\231\377\230\230\230\377\227\227\227\377\232\232\232\377\253"
  "\253\253\377ggg\377\0\0\0\377\246\246\246\377\303\303\303\377\266\266"
  "\266\377\271\271\271\377\203\270\270\270\377\21\302\302\302\377\327\327"
  "\327\377RRR\377\25\25\25\377\321\321\321\377\276\276\276\377\271\271"
  "\271\377\273\273\273\377\301\301\301\377\277\277\277\377\301\301\301"
  "\377\274\274\274\377\304\304\304\377\306\306\306\377\310\310\310\377"
  "\350\350\350\377ttt\377\207\0\0\0\377\7\206\206\206\377\243\243\243\377"
  "\230\230\230\377\227\227\227\377\233\233\233\377\252\252\252\377|||\377"
  "\202\0\0\0\377\3\331\331\331\377\273\273\273\377\271\271\271\377\202"
  "\270\270\270\377\10\267\267\267\377\305\305\305\377\327\327\327\377S"
  "SS\377\0\0\0\377\257\257\257\377\312\312\312\377\273\273\273\377\202"
  "\274\274\274\377\203\275\275\275\377\1\274\274\274\377\203\310\310\310"
  "\377\2\337\337\337\377\235\235\235\377\206\0\0\0\377\7\2\2\2\377\257"
  "\257\257\377\236\236\236\377\226\226\226\377\236\236\236\377\253\253"
  "\253\377www\377\202\0\0\0\377\2>>>\377\331\331\331\377\203\270\270\270"
  "\377\10\272\272\272\377\306\306\306\377\325\325\325\377@@@\377\0\0\0"
  "\377\26\26\26\377\341\341\341\377\300\300\300\377\204\275\275\275\377"
  "\4\276\276\276\377\275\275\275\377\300\300\300\377\312\312\312\377\202"
  "\307\307\307\377\2\343\343\343\377\202\202\202\377\206\0\0\0\377\2\2"
  "\2\2\377\245\245\245\377\202\243\243\243\377\2\256\256\256\377lll\377"
  "\203\0\0\0\377\10DDD\377\331\331\331\377\271\271\271\377\270\270\270"
  "\377\273\273\273\377\314\314\314\377\316\316\316\377%%%\377\202\0\0\0"
  "\377\2\204\204\204\377\327\327\327\377\203\275\275\275\377\12\273\273"
  "\273\377\277\277\277\377\316\316\316\377\300\300\300\377\305\305\305"
  "\377\314\314\314\377\310\310\310\377\311\311\311\377\357\357\357\377"
  "@@@\377\207\0\0\0\377\4<<<\377\236\236\236\377\235\235\235\377EEE\377"
  "\204\0\0\0\377\7\17\17\17\377\327\327\327\377\307\307\307\377\304\304"
  "\304\377\323\323\323\377\304\304\304\377\5\5\5\377\203\0\0\0\377\2\246"
  "\246\246\377\325\325\325\377\203\275\275\275\377\11\303\303\303\377\331"
  "\331\331\377\260\260\260\377\3\3\3\377\311\311\311\377\313\313\313\377"
  "\310\310\310\377\317\317\317\377\356\356\356\377\221\0\0\0\377\4JJJ\377"
  "\272\272\272\377\311\311\311\377\210\210\210\377\205\0\0\0\377\12SSS"
  "\377\346\346\346\377\307\307\307\377\301\301\301\377\315\315\315\377"
  "\340\340\340\377~~~\377\0\0\0\377%%%\377\351\351\351\377\202\310\310"
  "\310\377\2\330\330\330\377\233\233\233\377\233\0\0\0\377\5zzz\377\350"
  "\350\350\377\351\351\351\377\314\314\314\377888\377\202\0\0\0\377\2\207"
  "\207\207\377\345\345\345\377\202\307\307\307\377\2\330\330\330\377rr"
  "r\377\235\0\0\0\377\1\24\24\24\377\204\0\0\0\377\2ddd\377\350\350\350"
  "\377\202\310\310\310\377\4\324\324\324\377\263\263\263\377]]]\377\4\4"
  "\4\377\240\0\0\0\377\10\21\21\21\377\357\357\357\377\323\323\323\377"
  "\311\311\311\377\306\306\306\377\254\254\254\377\177\177\177\377\21\21"
  "\21\377\241\0\0\0\377\7XXX\377\340\340\340\377\327\327\327\377\276\276"
  "\276\377\255\255\255\377UUU\377\7\7\7\377\242\0\0\0\377\6\37\37\37\377"
  "RRR\377VVV\377111\377\10\10\10\377\0\0\0\377"};

==> photoprint_0.4.2~pre2.orig.tar.gz: photoprint-0.4.2-pre2/miscwidgets/squiggledata.cpp <==
/* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */

#ifdef __SUNPRO_C
#pragma align 4 (squiggle_data)
#endif
#ifdef __GNUC__
static const guint8 squiggle_data[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 squiggle_data[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2895) */
  "\0\0\13g"
  /* pixdata_type (0x2010002) */
  "\2\1\0\2"
  /* rowstride (160) */
  "\0\0\0\240"
  /* width (40) */
  "\0\0\0("
  /* height (30) */
  "\0\0\0\36"
  /* pixel_data: */
  "\212\0\0\0\377\4\5\5\5\377(((\377...\377\15\15\15\377\236\0\0\0\377\2"
  "\3\3\3\377\7\7\7\377\204\0\0\0\377\4PPP\377\211\211\211\377\200\200\200"
  "\377EEE\377\236\0\0\0\377\3'''\377!!!\377\10\10\10\377\202\0\0\0\377"
  "\5CCC\377\207\207\207\377\203\203\203\377\210\210\210\377VVV\377\202"
  "\0\0\0\377\4""555\377ppp\377aaa\377\24\24\24\377\227\0\0\0\377\7&&&\377"
  "AAA\377;;;\377\10\10\10\377\0\0\0\377999\377~~~\377\202\201\201\201\377"
  "\10\210\210\210\377\27\27\27\377\0\0\0\377KKK\377\210\210\210\377\205"
  "\205\205\377\204\204\204\377eee\377\203\0\0\0\377\5\35\35\35\377\200"
  "\200\200\377\243\243\243\377\207\207\207\377\26\26\26\377\216\0\0\0\377"
  "\22\5\5\5\377PPP\377QQQ\377>>>\377\0\0\0\377\34\34\34\377xxx\377\200"
  "\200\200\377\177\177\177\377\203\203\203\377YYY\377\0\0\0\377AAA\377"
  "\206\206\206\377\203\203\203\377~~~\377\205\205\205\377www\377\202\0"
  "\0\0\377\6jjj\377\254\254\254\377\246\246\246\377\243\243\243\377\251"
  "\251\251\377\223\223\223\377\216\0\0\0\377\16:::\377^^^\377YYY\377''"
  "'\377\0\0\0\377nnn\377|||\377}}}\377\177\177\177\377rrr\377\0\0\0\377"
  "555\377\205\205\205\377\177\177\177\377\202~~~\377\13\204\204\204\377"
  "KKK\377\0\0\0\377\223\223\223\377\247\247\247\377\231\231\231\377\232"
  "\232\232\377\233\233\233\377\241\241\241\377\251\251\251\377\5\5\5\377"
  "\215\0\0\0\377\6___\377bbb\377XXX\377\14\14\14\377ccc\377zzz\377\202"
  "}}}\377\4uuu\377---\377000\377\201\201\201\377\202~~~\377\202}}}\377"
  "\6sss\377\"\"\"\377\221\221\221\377\243\243\243\377\226\226\226\377\230"
  "\230\230\377\202\232\232\232\377\2\247\247\247\377\225\225\225\377\215"
  "\0\0\0\377\14\32\32\32\377mmm\377ddd\377GGG\377OOO\377www\377|||\377"
  "{{{\377uuu\377UUU\377===\377~~~\377\202|||\377\10\177\177\177\377|||"
  "\377sss\377^^^\377\212\212\212\377\240\240\240\377\225\225\225\377\224"
  "\224\224\377\202\233\233\233\377\3\235\235\235\377\262\262\262\37733"
  "3\377\214\0\0\0\377\33\2\2\2\377TTT\377kkk\377aaa\377___\377nnn\377x"
  "xx\377}}}\377uuu\377eee\377XXX\377zzz\377{{{\377zzz\377\200\200\200\377"
  "~~~\377vvv\377qqq\377\222\222\222\377\232\232\232\377\227\227\227\377"
  "\224\224\224\377\233\233\233\377\234\234\234\377\235\235\235\377\252"
  "\252\252\377\206\206\206\377\215\0\0\0\377\10\23\23\23\377ppp\377jjj"
  "\377ppp\377nnn\377rrr\377}}}\377www\377\202lll\377\21www\377{{{\377x"
  "xx\377\200\200\200\377\177\177\177\377xxx\377vvv\377\224\224\224\377"
  "\231\231\231\377\226\226\226\377\224\224\224\377\231\231\231\377\235"
  "\235\235\377\234\234\234\377\245\245\245\377\256\256\256\377\21\21\21"
  "\377\215\0\0\0\377\2'''\377uuu\377\202www\377\26lll\377www\377yyy\377"
  "ooo\377vvv\377uuu\377yyy\377vvv\377}}}\377\202\202\202\377zzz\377www"
  "\377\223\223\223\377\231\231\231\377\227\227\227\377\224\224\224\377"
  "\226\226\226\377\236\236\236\377\237\237\237\377\242\242\242\377\266"
  "\266\266\377FFF\377\216\0\0\0\377\1***\377\202yyy\377\26ttt\377mmm\377"
  "xxx\377qqq\377www\377yyy\377zzz\377yyy\377{{{\377\204\204\204\377\200"
  "\200\200\377zzz\377\215\215\215\377\231\231\231\377\227\227\227\377\225"
  "\225\225\377\221\221\221\377\237\237\237\377\243\243\243\377\244\244"
  "\244\377\262\262\262\377\177\177\177\377\202\0\0\0\377\4)))\377zzz\377"
  "\221\221\221\377PPP\377\211\0\0\0\377\10\20\20\20\377ddd\377ttt\377d"
  "dd\377nnn\377qqq\377uuu\377}}}\377\202yyy\377\1vvv\377\202\204\204\204"
  "\377\7\202\202\202\377\212\212\212\377\231\231\231\377\227\227\227\377"
  "\230\230\230\377\223\223\223\377\217\217\217\377\202\244\244\244\377"
  "\2\253\253\253\377\250\250\250\377\202\0\0\0\377\6\247\247\247\377\334"
  "\334\334\377\323\323\323\377\321\321\321\377\334\334\334\377~~~\377\212"
  "\0\0\0\377\15\13\13\13\377***\377vvv\377xxx\377\177\177\177\377|||\377"
  "{{{\377ttt\377}}}\377\210\210\210\377\205\205\205\377\211\211\211\377"
  "\230\230\230\377\202\227\227\227\377\17\224\224\224\377vvv\377\250\250"
  "\250\377\253\253\253\377\250\250\250\377\260\260\260\377\34\34\34\377"
  "333\377\321\321\321\377\316\316\316\377\275\275\275\377\271\271\271\377"
  "\273\273\273\377\304\304\304\377\336\336\336\377\213\0\0\0\377\7ppp\377"
  "}}}\377~~~\377}}}\377{{{\377www\377ppp\377\203\212\212\212\377\11\230"
  "\230\230\377\227\227\227\377\230\230\230\377\227\227\227\377\201\201"
  "\201\377\245\245\245\377\264\264\264\377\257\257\257\377\255\255\255"
  "\377\202uuu\377\2\323\323\323\377\304\304\304\377\202\271\271\271\377"
  "\202\274\274\274\377\3\275\275\275\377\344\344\344\377&&&\377\211\0\0"
  "\0\377\27:::\377\202\202\202\377\201\201\201\377\177\177\177\377}}}\377"
  "zzz\377fff\377\204\204\204\377\220\220\220\377\215\215\215\377\227\227"
  "\227\377\231\231\231\377\227\227\227\377\233\233\233\377|||\377\225\225"
  "\225\377\267\267\267\377\263\263\263\377\260\260\260\377\255\255\255"
  "\377\250\250\250\377\304\304\304\377\275\275\275\377\202\270\270\270"
  "\377\1\271\271\271\377\203\274\274\274\377\2\345\345\345\377\21\21\21"
  "\377\211\0\0\0\377\2hhh\377\206\206\206\377\202\200\200\200\377\22\177"
  "\177\177\377eee\377hhh\377\225\225\225\377\220\220\220\377\226\226\226"
  "\377\232\232\232\377\226\226\226\377\237\237\237\377\223\223\223\377"
  "QQQ\377\277\277\277\377\265\265\265\377\260\260\260\377\261\261\261\377"
  "\272\272\272\377\273\273\273\377\271\271\271\377\203\270\270\270\377"
  "\1\271\271\271\377\202\272\272\272\377\2\302\302\302\377\324\324\324"
  "\377\212\0\0\0\377\7fff\377\205\205\205\377\177\177\177\377\205\205\205"
  "\377sss\377666\377\227\227\227\377\202\226\226\226\377\11\230\230\230"
  "\377\227\227\227\377\237\237\237\377\246\246\246\377\34\34\34\377\252"
  "\252\252\377\275\275\275\377\263\263\263\377\262\262\262\377\204\270"
  "\270\270\377\4\275\275\275\377\276\276\276\377\265\265\265\377\276\276"
  "\276\377\202\272\272\272\377\7\302\302\302\377zzz\377\0\0\0\377]]]\377"
  "\255\255\255\377\310\310\310\377\222\222\222\377\205\0\0\0\377\22""0"
  "00\377|||\377\205\205\205\377www\377\16\16\16\377ooo\377\234\234\234"
  "\377\226\226\226\377\230\230\230\377\227\227\227\377\235\235\235\377"
  "\255\255\255\377DDD\377###\377\314\314\314\377\264\264\264\377\265\265"
  "\265\377\267\267\267\377\203\270\270\270\377\5\301\301\301\377\317\317"
  "\317\377nnn\377\235\235\235\377\275\275\275\377\202\272\272\272\377\10"
  "\302\302\302\377\240\240\240\377\321\321\321\377\333\333\333\377\320"
  "\320\320\377\322\322\322\377\340\340\340\377\327\327\327\377\205\0\0"
  "\0\377\20\36\36\36\377222\377\0\0\0\377\36\36\36\377\247\247\247\377"
  "\231\231\231\377\230\230\230\377\227\227\227\377\232\232\232\377\253"
  "\253\253\377ggg\377\0\0\0\377\246\246\246\377\303\303\303\377\266\266"
  "\266\377\271\271\271\377\203\270\270\270\377\21\302\302\302\377\327\327"
  "\327\377RRR\377\25\25\25\377\321\321\321\377\276\276\276\377\271\271"
  "\271\377\273\273\273\377\301\301\301\377\277\277\277\377\301\301\301"
  "\377\274\274\274\377\304\304\304\377\306\306\306\377\310\310\310\377"
  "\350\350\350\377ttt\377\207\0\0\0\377\7\206\206\206\377\243\243\243\377"
  "\230\230\230\377\227\227\227\377\233\233\233\377\252\252\252\377|||\377"
  "\202\0\0\0\377\3\331\331\331\377\273\273\273\377\271\271\271\377\202"
  "\270\270\270\377\10\267\267\267\377\305\305\305\377\327\327\327\377S"
  "SS\377\0\0\0\377\257\257\257\377\312\312\312\377\273\273\273\377\202"
  "\274\274\274\377\203\275\275\275\377\1\274\274\274\377\203\310\310\310"
  "\377\2\337\337\337\377\235\235\235\377\206\0\0\0\377\7\2\2\2\377\257"
  "\257\257\377\236\236\236\377\226\226\226\377\236\236\236\377\253\253"
  "\253\377www\377\202\0\0\0\377\2>>>\377\331\331\331\377\203\270\270\270"
  "\377\10\272\272\272\377\306\306\306\377\325\325\325\377@@@\377\0\0\0"
  "\377\26\26\26\377\341\341\341\377\300\300\300\377\204\275\275\275\377"
  "\4\276\276\276\377\275\275\275\377\300\300\300\377\312\312\312\377\202"
  "\307\307\307\377\2\343\343\343\377\202\202\202\377\206\0\0\0\377\2\2"
  "\2\2\377\245\245\245\377\202\243\243\243\377\2\256\256\256\377lll\377"
  "\203\0\0\0\377\10DDD\377\331\331\331\377\271\271\271\377\270\270\270"
  "\377\273\273\273\377\314\314\314\377\316\316\316\377%%%\377\202\0\0\0"
  "\377\2\204\204\204\377\327\327\327\377\203\275\275\275\377\12\273\273"
  "\273\377\277\277\277\377\316\316\316\377\300\300\300\377\305\305\305"
  "\377\314\314\314\377\310\310\310\377\311\311\311\377\357\357\357\377"
  "@@@\377\207\0\0\0\377\4<<<\377\236\236\236\377\235\235\235\377EEE\377"
  "\204\0\0\0\377\7\17\17\17\377\327\327\327\377\307\307\307\377\304\304"
  "\304\377\323\323\323\377\304\304\304\377\5\5\5\377\203\0\0\0\377\2\246"
  "\246\246\377\325\325\325\377\203\275\275\275\377\11\303\303\303\377\331"
  "\331\331\377\260\260\260\377\3\3\3\377\311\311\311\377\313\313\313\377"
  "\310\310\310\377\317\317\317\377\356\356\356\377\221\0\0\0\377\4JJJ\377"
  "\272\272\272\377\311\311\311\377\210\210\210\377\205\0\0\0\377\12SSS"
  "\377\346\346\346\377\307\307\307\377\301\301\301\377\315\315\315\377"
  "\340\340\340\377~~~\377\0\0\0\377%%%\377\351\351\351\377\202\310\310"
  "\310\377\2\330\330\330\377\233\233\233\377\233\0\0\0\377\5zzz\377\350"
  "\350\350\377\351\351\351\377\314\314\314\377888\377\202\0\0\0\377\2\207"
  "\207\207\377\345\345\345\377\202\307\307\307\377\2\330\330\330\377rr"
  "r\377\235\0\0\0\377\1\24\24\24\377\204\0\0\0\377\2ddd\377\350\350\350"
  "\377\202\310\310\310\377\4\324\324\324\377\263\263\263\377]]]\377\4\4"
  "\4\377\240\0\0\0\377\10\21\21\21\377\357\357\357\377\323\323\323\377"
  "\311\311\311\377\306\306\306\377\254\254\254\377\177\177\177\377\21\21"
  "\21\377\241\0\0\0\377\7XXX\377\340\340\340\377\327\327\327\377\276\276"
  "\276\377\255\255\255\377UUU\377\7\7\7\377\242\0\0\0\377\6\37\37\37\377"
  "RRR\377VVV\377111\377\10\10\10\377\0\0\0\377"};
